﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Input;

namespace XNA4InputHandler
{
    class InputHandler : GameComponent
    {        
        public GamePadState CurrentGamePadState;
        public GamePadState PrevGamePadState;
        public KeyboardState CurrentKeyboardState;
        public KeyboardState PrevKeyboardState;
        public MouseState CurrentMouseState;
        public MouseState PrevMouseState; 

        private Point prevMouseLocation;  
        private Vector2 mouseMoved;  
        public Vector2 MouseMoved  
        {  
            get { return mouseMoved; }  
        }

        public InputHandler(Game game) : base(game)
        {
            Enabled = true;
        }

        public override void Update(GameTime gameTime)
        {
            PrevGamePadState = CurrentGamePadState;
            CurrentGamePadState = GamePad.GetState(PlayerIndex.One);

            PrevKeyboardState = CurrentKeyboardState;
            CurrentKeyboardState = Keyboard.GetState();

            PrevMouseState = CurrentMouseState;
            CurrentMouseState = Mouse.GetState(); 

            mouseMoved = new Vector2(PrevMouseState.X - CurrentMouseState.X, PrevMouseState.Y - CurrentMouseState.Y);
            prevMouseLocation = new Point(CurrentMouseState.X, CurrentMouseState.Y);
        }

        public bool IsKeyPressed(Keys key)
        {
            return (CurrentKeyboardState.IsKeyDown(key) && PrevKeyboardState.IsKeyUp(key));
        }

        public bool IsKeyDown(Keys key)
        {
            return CurrentKeyboardState.IsKeyDown(key);
        }

        public bool PauseGame  
        {  
            get 
            {  
                return IsKeyPressed(Keys.Escape) ||
                    (CurrentGamePadState.Buttons.Back == ButtonState.Pressed &&  
                    PrevGamePadState.Buttons.Back == ButtonState.Released) ||
                    (CurrentGamePadState.Buttons.Start == ButtonState.Pressed &&  
                    PrevGamePadState.Buttons.Start == ButtonState.Released);  
            }  
        }
    }
}
